EXPORTS
	??0CStateMachine@@IAE@XZ @ 1 NONAME ; protected: __thiscall CStateMachine::CStateMachine(void)
	??1CStateMachine@@UAE@XZ @ 2 NONAME ; public: virtual __thiscall CStateMachine::~CStateMachine(void)
	?Cancel@CStateMachine@@QAEXH@Z @ 3 NONAME ; public: void __thiscall CStateMachine::Cancel(int)
	?DoCancel@CStateMachine@@MAEXXZ @ 4 NONAME ; protected: virtual void __thiscall CStateMachine::DoCancel(void)
	?OnCompletion@CStateMachine@@MAEXXZ @ 5 NONAME ; protected: virtual void __thiscall CStateMachine::OnCompletion(void)
	?OnError@CStateMachine@@IAEXXZ @ 6 NONAME ; protected: void __thiscall CStateMachine::OnError(void)
	?ReAllocL@CStateMachine@@QAEPAVHBufC8@@H@Z @ 7 NONAME ; public: class HBufC8 * __thiscall CStateMachine::ReAllocL(int)
	?RunError@CStateMachine@@MAEHH@Z @ 8 NONAME ; protected: virtual int __thiscall CStateMachine::RunError(int)
	?RunL@CStateMachine@@MAEXXZ @ 9 NONAME ; protected: virtual void __thiscall CStateMachine::RunL(void)
	?Start@CStateMachine@@QAEXPAVTRequestStatus@@PAVCAsynchEvent@@PAVMStateMachineNotify@@@Z @ 10 NONAME ; public: void __thiscall CStateMachine::Start(class TRequestStatus *,class CAsynchEvent *,class MStateMachineNotify *)
	?Accept@ACore@NetStateMachine@@SAHABUTStateTriple@2@PAXH@Z @ 11 NONAME ; int NetStateMachine::ACore::Accept(struct NetStateMachine::TStateTriple const &, void *, int)
	?Cancel@ACore@NetStateMachine@@QAEXPAX@Z @ 12 NONAME ; void NetStateMachine::ACore::Cancel(void *)
	?Do@ACore@NetStateMachine@@SAHABUTStateTriple@2@PAXAAVTDes8@@@Z @ 13 NONAME ; int NetStateMachine::ACore::Do(struct NetStateMachine::TStateTriple const &, void *, class TDes8 &)
	?DoCurrent@ACore@NetStateMachine@@QAEXPAX@Z @ 14 NONAME ; void NetStateMachine::ACore::DoCurrent(void *)
	?FindNext@ACore@NetStateMachine@@SAPBUTStateTriple@2@ABU32@H@Z @ 15 NONAME ; struct NetStateMachine::TStateTriple const * NetStateMachine::ACore::FindNext(struct NetStateMachine::TStateTriple const &, int)
	?IsIdle@ACore@NetStateMachine@@UBEHXZ @ 16 NONAME ; int NetStateMachine::ACore::IsIdle(void) const
	?Next@ACore@NetStateMachine@@QAEHPAX@Z @ 17 NONAME ; int NetStateMachine::ACore::Next(void *)
	?SetIdle@ACore@NetStateMachine@@UAEXXZ @ 18 NONAME ; void NetStateMachine::ACore::SetIdle(void)
	?Start@ACore@NetStateMachine@@QAEXPAXABUTStateTriple@2@@Z @ 19 NONAME ; void NetStateMachine::ACore::Start(void *, struct NetStateMachine::TStateTriple const &)

